==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Input/opus/translations/opus_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="48"/>
        <source>Opus Plugin</source>
        <translation>Wtyczka Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="51"/>
        <source>Ogg Opus Files</source>
        <translation>Pliki Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="122"/>
        <source>About Opus Audio Plugin</source>
        <translation>O wtyczce Opus Audio</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="123"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Wtyczka Opus Audio dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="124"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="125"/>
        <source>This plugin includes code from TagLib library</source>
        <translation>Ta wtyczka używa kodu z biblioteki TagLib</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>Wielkość pliku</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qmmp-0.9.10.tar.bz2: qmmp-0.9.10/src/plugins/Input/opus/translations/opus_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="47"/>
        <source>Opus Plugin</source>
        <translation>Wtyczka Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="50"/>
        <source>Ogg Opus Files</source>
        <translation>Pliki Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="124"/>
        <source>About Opus Audio Plugin</source>
        <translation>O wtyczce Opus Audio</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="125"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Wtyczka Opus Audio dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="126"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="127"/>
        <source>This plugin includes code from TagLib library</source>
        <translation>Ta wtyczka używa kodu z biblioteki TagLib</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="54"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>File size</source>
        <translation>Wielkość pliku</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
